CREATE TABLE TRANSACTION_EXPORT_TYPE (
  CODE VARCHAR2(3 CHAR) NOT NULL,
  DESCRIPTION VARCHAR2(100 CHAR),
  INTERNAL_DESCRIPTION VARCHAR2(100 CHAR),
  CONSTRAINT TRANSACTION_EXPORT_TYPE_PK PRIMARY KEY (CODE)
);

INSERT INTO TRANSACTION_EXPORT_TYPE(CODE, DESCRIPTION, INTERNAL_DESCRIPTION) VALUES
('INV', 'Invoices', 'Invoices');

INSERT INTO TRANSACTION_EXPORT_TYPE(CODE, DESCRIPTION, INTERNAL_DESCRIPTION) VALUES
('PAY', 'Payments', 'Payments');


 CREATE TABLE TRANSACTION_EXPORT_FORMAT (
  CODE VARCHAR2(10 CHAR) NOT NULL,
  DESCRIPTION VARCHAR2(100 CHAR),
  INTERNAL_DESCRIPTION VARCHAR2(100 CHAR),
  CONSTRAINT TRANSACTION_EXPORT_FORMAT_PK PRIMARY KEY (CODE)
);

INSERT INTO TRANSACTION_EXPORT_FORMAT(CODE, DESCRIPTION, INTERNAL_DESCRIPTION) VALUES
('ABA', 'ABA', 'ABA');


CREATE TABLE TRANSACTION_EXPORT (
	ID_TRANSACTION_EXPORT NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(250 CHAR),
  INTERNAL_DESCRIPTION VARCHAR2(250 CHAR),
  TRANSACTION_TYPE VARCHAR2(3 CHAR),
  EXPORT_FORMAT VARCHAR2(3 CHAR),
  EXPORT_FILENAME VARCHAR2(100 CHAR),
  NNLOCATION_ID NUMBER,
  USER_IDENTIFICATION_NUMBER VARCHAR2(100 CHAR),
  TRANSACTION_RECORD_TYPE VARCHAR2(200 CHAR),
  EXCLUDE_NEGATIVE_TRANSACTIONS VARCHAR2(1 CHAR),
  EXCLUDE_CUST_POSITIVE_BALANCE VARCHAR2(1 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT TRANSACTION_TRANS_TYPE_FK FOREIGN KEY (TRANSACTION_TYPE) REFERENCES TRANSACTION_EXPORT_TYPE(CODE),
  CONSTRAINT TRANSACTION_EXPORT_FORMAT_FK FOREIGN KEY (EXPORT_FORMAT) REFERENCES TRANSACTION_EXPORT_FORMAT(CODE),
  CONSTRAINT TRANSACTION_EXPORT_PK PRIMARY KEY (ID_TRANSACTION_EXPORT)
);


CREATE SEQUENCE TRANSACTION_EXPORT_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;


CREATE OR REPLACE VIEW V_TRANSACTION_EXPORT AS (
  SELECT T.ID_TRANSACTION_EXPORT, T.DESCRIPTION, T.INTERNAL_DESCRIPTION, T.TRANSACTION_TYPE, T.EXPORT_FORMAT, T.EXPORT_FILENAME, T.NNLOCATION_ID, T.USER_IDENTIFICATION_NUMBER, 
  T.TRANSACTION_RECORD_TYPE, T.EXCLUDE_NEGATIVE_TRANSACTIONS, T.ACTIVE,
  TET.DESCRIPTION AS TRANSACTION_TYPE_DESCRIPTION, TEF.DESCRIPTION AS EXPORT_FORMAT_DESCRIPTION
	FROM TRANSACTION_EXPORT T
  LEFT OUTER JOIN TRANSACTION_EXPORT_TYPE TET ON TET.CODE = T.TRANSACTION_TYPE
  LEFT OUTER JOIN TRANSACTION_EXPORT_FORMAT TEF ON TEF.CODE = T.EXPORT_FORMAT
);

CREATE OR REPLACE VIEW V_SALDKONT AS (
	SELECT S.ID_SALDKONT AS SALDKONT_ID_SALDKONT, S.N_RACUNA AS SALDKONT_N_RACUNA, S.DATUM AS SALDKONT_DATUM, S.ZA_PLACILO AS SALDKONT_ZA_PLACILO, S.PORABLJENO AS SALDKONT_PORABLJENO, S.VALUTA_RN AS SALDKONT_VALUTA_RN,
  S.DATUM_VALUTACIJE AS SALDKONT_DATUM_VALUTACIJE, S.VRSTA_RACUNA AS SALDKONT_VRSTA_RACUNA, S.USER_KREIRANJA AS SALDKONT_USER_KREIRANJA, S.DATUM_KREIRANJA AS SALDKONT_DATUM_KREIRANJA,
  S.USER_SPREMEMBE AS SALDKONT_USER_SPREMEMBE, S.DATUM_SPREMEMBE AS SALDKONT_DATUM_SPREMEMBE, S.ID_KUPCA AS SALDKONT_ID_KUPCA, S.ID_PLOVILA AS SALDKONT_ID_PLOVILA, S.ZAPRTO AS SALDKONT_ZAPRTO,
  S.SDK_RN_PL AS SALDKONT_SDK_RN_PL, S.SDK_RN_TIP AS SALDKONT_SDK_RN_TIP, S.LASTNIK_OBVESCEN AS SALDKONT_LASTNIK_OBVESCEN, S.STORNO AS SALDKONT_STORNO, S.KOMENTAR AS SALDKONT_KOMENTAR, S.ID_CARDS AS SALDKONT_ID_CARDS, S.ZNESEK AS SALDKONT_ZNESEK,
  S.PROTIVREDNOST AS SALDKONT_PROTIVREDNOST, CASE WHEN S.VALUTA_RN = (SELECT DOMACAVALUTA FROM PARAM) THEN 'Y' ELSE 'N' END AS SALDKONT_DOMESTIC, S.TECAJ_PRERACUN AS SALDKONT_TECAJ_PRERACUN, S.N_KNJIZBE AS SALDKONT_N_KNJIZBE,
  CASE WHEN S.SDK_RN_TIP = 'P' AND EXISTS (SELECT * FROM SALDKONT WHERE ID_SALDKONT = S.ID_SALDKONT_GEN AND SDK_RN_TIP = 'I' AND ZAPRTO = 1) THEN 'Y' ELSE 'N' END AS REC_INV_HAS_CLOSED_ISSUED_INV, 
  S.NCARD AS SALDKONT_NCARD, S.N_LISTINE AS SALDKONT_NLISTINE, S.NNLOCATION_ID AS SALDKONT_NNLOCATION_ID, S.NNFIRMA_ID AS SALDKONT_NNFIRMA_ID, S.ID_DN AS SALDKONT_ID_DN, 
  S.PAYMENT_RESPONSE_ID AS SALDKONT_PAYMENT_RESPONSE_ID, S.STATUS AS SALDKONT_STATUS, S.ID_SALDKONT_GEN AS SALDKONT_ID_SALDKONT_GEN, S.ID_EXCHANGE AS SALDKONT_ID_EXCHANGE, S.ID_RACUNA AS SALDKONT_ID_RACUNA,
  S.ID_BATCH AS SALDKONT_ID_BATCH, S.DAVEK_NA_STORITVE AS SALDKONT_DAVEK_NA_STORITVE, S.DAVEK_NA_MATERIAL AS SALDKONT_DAVEK_NA_MATERIAL, S.POPUST AS SALDKONT_POPUST, S.DATUM_ORG AS SALDKONT_DATUM_ORG, 
  S.DATUM_PLACILA AS SALDKONT_DATUM_PLACILA, S.VALUTA_PL AS SALDKONT_VALUTA_PL, S.TECAJ_PL AS SALDKONT_TECAJ_PL, S.TECAJ_VALUTE AS SALDKONT_TECAJ_VALUTE, S.STORNONR AS SALDKONT_STORNO_NR, 
  S.BLAGAJNA AS SALDKONT_BLAGAJNA, S.LOKAC AS SALDKONT_LOKAC,
  R.SUBLEASE_OD AS RACUN_DATA_SUBLEASE_OD, R.SUBLEASE_DO AS RACUN_DATA_SUBLEASE_DO, N.OPIS AS M_NNSTOMAR_OPIS, N.KAT AS M_NNSTOMAR_KAT, N.TIMEKAT AS M_NNSTOMAR_TIMEKAT, N.SUBLEASE AS M_NNSTOMAR_SUBLEASE,
  D.ID_PRINT_DOK AS PRINT_DOK_ID_PRINT_DOK, D.STEVILKA AS PRINT_DOK_STEVILKA, D.OPIS AS PRINT_DOK_OPIS, D.DATOTEKA AS PRINT_DOK_DATOTEKA, D.PDF AS PRINT_DOK_PDF, D.OBJAVI AS PRINT_DOK_OBJAVI,
  K.IME AS KUPCI_IME, K.PRIIMEK AS KUPCI_PRIIMEK, K.SALDAKONTI_SIT AS KUPCI_SALDAKONTI_SIT, K.NASLOV AS KUPCI_NASLOV, K.POSTA AS KUPCI_POSTA, K.MESTO AS KUPCI_MESTO, K.DAVCNA_STEVILKA AS KUPCI_DAVCNA_STEVILKA,
  K.SIFRA_DOB AS KUPCI_SIFRA_DOB, K.INT_CODE AS KUPCI_INT_CODE, P.IME AS PLOVILA_IME,
  KND.OZNAKA AS KUPCI_NDRZAVA_OZNAKA, NC.OPIS AS NNCARDS_OPIS, NC.VRSTA_DENARJA AS NNCARDS_VRSTA_DENARJA, 
  M.ID_PRIVEZ AS M_STORITVE_ID_PRIVEZ, NNP.N_PRIVEZA AS M_STORITVE_NNPRIVEZ_N_PRIVEZA, M.SUBLEASE_PAYMENT AS M_STORITVE_SUBLEASE_PAYMENT, NKNJ.SLO AS NKNJIZBA_OPIS, NKNJ.INTERNI_OPIS AS NKNJIZBA_INTERNI_OPIS, 
  NKNJ.DEPOSIT AS NKNJIZBA_DEPOSIT, PR.STATUS_CODE AS PAYMENT_RESPONSE_STATUS_CODE, PR.MESSAGE AS PAYMENT_RESPONSE_MESSAGE, PR.INTERNAL_STATUS AS PAYMENT_RESPONSE_INT_STATUS
	FROM SALDKONT S
  LEFT OUTER JOIN RACUN_DATA R ON R.ID_SALDKONT = S.ID_SALDKONT
  LEFT OUTER JOIN M_STORITVE M ON M.ID_STORITVE = R.ID_STORITVE
  LEFT OUTER JOIN M_NNSTOMAR N ON N.SIFRA = M.STORITEV
  LEFT OUTER JOIN PRINT_DOK D ON D.MODUL = S.VRSTA_RACUNA AND D.REFERENCA = S.ID_SALDKONT
  LEFT OUTER JOIN KUPCI K ON K.ID = S.ID_KUPCA
  LEFT OUTER JOIN PLOVILA P ON P.ID = S.ID_PLOVILA
  LEFT OUTER JOIN NNCARDS NC ON NC.ID_CARDS = S.ID_CARDS
  LEFT OUTER JOIN NNDRZAVE KND ON KND.SIFRA = K.NDRZAVA
  LEFT OUTER JOIN NNPRIVEZ NNP ON NNP.ID_PRIVEZ = M.ID_PRIVEZ
  LEFT OUTER JOIN NKNJIZBA NKNJ ON NKNJ.SALDKONT = S.VRSTA_RACUNA
  LEFT OUTER JOIN PAYMENT_RESPONSE PR ON PR.ID = S.PAYMENT_RESPONSE_ID
  WHERE R.ZAP_ST IS NULL OR R.ZAP_ST = 1
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1319, SYSDATE, '5.5', 1239, 'Transaction export')
;